==> exit-options_23.2.03.tar.xz: exit-options-23.2.03/translations/exit-options_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="30"/>
        <source>Lock Screen</source>
        <translation>Bloquear Pantalla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="31"/>
        <source>Log Out</source>
        <translation>Cerrar sesión</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="32"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="33"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="34"/>
        <source>Shutdown</source>
        <translation>Apagar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="42"/>
        <location filename="../main.cpp" line="50"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Ventana emergente con opciones de salida para MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>Display buttons in a vertical window</source>
        <translation>Mostrar los botones en una ventana vertical</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Mostrar los botones en una ventana horizontal</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Timeout duration in seconds</source>
        <translation>Tiempo de espera en segundos</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>utilice -v, --vertical, para mostrar los botones verticalmente
utilice -h, --horizontal, para mostrar los botones horizontalmente.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Uso: exit-options [opciones]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Options:</source>
        <translation>Opciones:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>  -h, --horizontal	 Opción de mostrar los botones horizontalmente</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>  -v, --vertical	 Opción de mostrar los botones verticalmente</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>-t, --timeout &lt;sec&gt;	 Duración del tiempo de espera en segundos
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>La opción de orientación de pantalla utilizada se recordará y se utilizará la próxima vez que inicie la aplicación</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>Alternativamente, puede establecer la opción &apos;layout=horizontal&apos; o &apos;layout=vertical&apos; en ~/.config/MX-Linux/exit-options.conf</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>Puede definir iconos personalizados añadiendo IconName=/path/iconame.ext en el archivo exit-options.conf. Los nombres de los iconos que se reasignan: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> exit-options_23.5.01.tar.xz: exit-options-23.5.01/translations/exit-options_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Lock Screen</source>
        <translation>Bloquear Pantalla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Log Out</source>
        <translation>Cerrar sesión</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="23"/>
        <source>Shutdown</source>
        <translation>Apagar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="42"/>
        <location filename="../main.cpp" line="50"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Ventana emergente con opciones de salida para MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>Display buttons in a vertical window</source>
        <translation>Mostrar los botones en una ventana vertical</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Mostrar los botones en una ventana horizontal</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Timeout duration in seconds</source>
        <translation>Tiempo de espera en segundos</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>utilice -v, --vertical, para mostrar los botones verticalmente
utilice -h, --horizontal, para mostrar los botones horizontalmente.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Uso: exit-options [opciones]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Options:</source>
        <translation>Opciones:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>  -h, --horizontal	 Opción de mostrar los botones horizontalmente</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>  -v, --vertical	 Opción de mostrar los botones verticalmente</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>-t, --timeout &lt;sec&gt;	 Duración del tiempo de espera en segundos
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>La opción de orientación de pantalla utilizada se recordará y se utilizará la próxima vez que inicie la aplicación</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>Alternativamente, puede establecer la opción &apos;layout=horizontal&apos; o &apos;layout=vertical&apos; en ~/.config/MX-Linux/exit-options.conf</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>Puede definir iconos personalizados añadiendo IconName=/path/iconame.ext en el archivo exit-options.conf. Los nombres de los iconos que se reasignan: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>Otras opciones que se pueden configurar en el archivo exit-options.conf: %1</translation>
    </message>
</context>
</TS>
